@@ -4,14 +4,12 @@ from kpc_nifi_utils.args.mongodb import MongoArgs
 from kpc_nifi_utils.args.mssql import MSSqlArgs
 from kpc_nifi_utils.args.postgresql import PostgreSqlArgs
 from kpc_nifi_utils.args.s3 import S3Args
-from kpc_nifi_utils.args.snowflake import SnowflakeArgs
 from kpc_nifi_utils.common.args_parser import Args
 from kpc_nifi_utils.common.json_encoder import EnhancedJSONEncoder
 from kpc_nifi_utils.common.singleton import singleton
 from kpc_nifi_utils.connector.mongo_connector import MongoConnector
 from kpc_nifi_utils.connector.mssql_connector import MSSqlConnector
 from kpc_nifi_utils.connector.postgresql_connector import PostgreSqlConnector
-from kpc_nifi_utils.connector.snowflake_connector import SnowflakeConnector
 from kpc_nifi_utils.nifi.execute_stream_command import Command
 from kpc_nifi_utils.nifi.execute_stream_command import Receiver
 from kpc_nifi_utils.nifi.execute_stream_command import Sender
