@@ -24,7 +24,7 @@ class S3Parser:
             now = datetime_group
 
         if date_sep:
-            res = '{}/{}'.format(prefix, now.strftime("%Y/%m/%d/%H:%M:%S.%f"))
+            res = '{}/{}'.format(prefix, now.strftime("%Y/%m/%d/%H%M%S"))
         else:
             res = '{}'.format(prefix)
 
